# Source me!
# vim: set sts=4 sw=4 et :

TRACKER_MINER_SCHEMA="org.freedesktop.Tracker.Miner.Files"
TRACKER_CONTROL="${TRACKER_CONTROL:-tracker-control}"
TRACKER_INFO="${TRACKER_INFO:-tracker-info}"

_reset_tracker_config() {
    # Flush all configuration, processes, and databases
    tracker-control -r -c
    reset_gsettings_schema "${TRACKER_MINER_SCHEMA}"
}

_monitor_indexing_status() {
    ${TRACKER_CONTROL} -F > ${TRACKER_MINER_LOG} &
    TRACKER_MONITOR_PID=$!
    # Sync after writing to log
    sync
}

# Wait till tracker-store commits all data
_wait_tracker_store_commit() {
    ${GDBUS} call --session \
        --dest org.freedesktop.Tracker1 \
        --object-path /org/freedesktop/Tracker1/Status \
        --method org.freedesktop.Tracker1.Status.Wait
    # The Resources.{BatchCommit,Sync} DBus methods are not enough to get rid
    # of the race condition between completion of indexing and commit of all 
    # data to disk, hence we flush tracker databases to disk manually
    sync
    _sleep 3
}

_kill_monitor() {
    kill -s TERM ${TRACKER_MONITOR_PID}
}

_spin_on_indexing_restart() {
    # Sync before file access
    sync
    # Spin till Tracker picks up changes and starts to re-index them
    while ! grep -ae "File System.*Processing" "${TRACKER_MINER_LOG}"; do
        sleep 0.1
        tail -n 1 "${TRACKER_MINER_LOG}" | grep -e "File System"
    done
}

_spin_on_indexing_finish() {
    # Sync before file access
    sync
    # Spin till Tracker initialises and finishes indexing
    while ! grep -ae "File System.*Idle" "${TRACKER_MINER_LOG}"; do
        sleep 0.1
        tail -n 1 "${TRACKER_MINER_LOG}" | grep -e "File System"
    done
    _wait_tracker_store_commit
}

_is_indexed() {
    _sleep 3
    ${TRACKER_INFO} "${@}" | grep -qe "'tracker:"
}

_is_playable() {
    ${TRACKER_INFO} "${@}" | grep -qe "'bosch:playable' = 'true'"
}

_is_not_indexed() {
    ! _is_indexed
}

_check_index_status() {
    local j wait_t res ret=0
    local check_function=$1
    local err_msg=$2
    shift 2
    # Check if all the files have been indexed
    for j in "$@"; do
        ${check_function} "${j}"
        # Complain for each file that wasn't indexed, and set the retcode
        if [[ "$?" -ne 0 ]]; then
            whine "${err_msg} '$j'!"
            ret=1
        fi
    done
    return ${ret}
}

_check_args_indexed() {
    _check_index_status _is_indexed "Tracker didn't index the file" "$@"
}

_check_args_not_indexed() {
    _check_index_status _is_not_indexed "Tracker *did* index the file" "$@"
}

_check_args_playable() {
    _check_index_status _is_playable "Tracker didn't set playable flag" "$@"
}

_do_initial_indexing() {
    # Write all data out to disk, to avoid races
    sync
    # Begin indexing
    ${TRACKER_CONTROL} -s 
    _monitor_indexing_status
    # Wait for indexing to complete
    _spin_on_indexing_finish
}

_get_tracker_info_values() {
    local id=$1
    local key=$2
    ${TRACKER_INFO} "$id" | sed -ne "s/\s\+'$key' = '\(.*\)'/\1/p"
}
