#!/bin/bash
# vim: set sts=4 sw=4 et tw=0 :

set -e

TESTDIR=$(cd $(dirname $0); pwd; cd - &>/dev/null)
. "${TESTDIR}/config.sh"
. "${TESTDIR}/../../common/tracker-utils.sh"

#########
# Setup #
#########
trap "setup_failure" ERR

# Need a DBus session for this test
ensure_dbus_session

setup_success

###########
# Execute #
###########
test_removable_index_status() {
    gsettings_key_is "${TRACKER_MINER_SCHEMA}" index-removable-devices true \
        || return 1

    # How long we should store data for files on removable media since the last
    # time it was mounted, in days. This number is arbitrary but it needs to be
    # reasonably large given that the penalty for aggressive cleanup is a slow
    # indexing process for media the user probably wants to access immediately
    gsettings_key_is "${TRACKER_MINER_SCHEMA}" removable-days-threshold 60 \
        || return 1

    # Never wait before starting to mine
    gsettings_key_is "${TRACKER_MINER_SCHEMA}" initial-sleep 0 || return 1
    gsettings_key_is "${TRACKER_MINER_SCHEMA}" sched-idle "'never'" || return 1
    gsettings_key_is "${TRACKER_MINER_SCHEMA}" enable-monitors true || return 1
}

test_journal_disabled() {
    local output=$(objdump -T /usr/lib*/tracker*/libtracker-data.so.0)
    grep -qe tracker_db_journal_init <<<"${output}" && return 1
    return 0
}

test_monitoring_enabled() {
    gsettings_key_is "${TRACKER_MINER_SCHEMA}" enable-monitors true
}

test_writeback_disabled() {
    gsettings_key_is "${TRACKER_MINER_SCHEMA}" enable-writeback false
}

trap "test_failure" ERR

src_test_pass <<-EOF
test_removable_index_status
test_journal_disabled
test_monitoring_enabled
EOF
#test_writeback_disabled

test_success
