/* vim: set sts=4 sw=4 et tw=0 :
 *
 * Short program to query for media files based on metadata
 *
 */

#include <tracker-sparql.h>

static gchar *audio_album = NULL;
static gchar *audio_artist = NULL;
static gchar *audio_title = NULL;
static gchar *audio_filter = NULL;

static GOptionEntry entries[] = 
{
    { "album", 0, 0, G_OPTION_ARG_STRING, &audio_album, "Find matching albums", "<album>" },
    { "artist", 0, 0, G_OPTION_ARG_STRING, &audio_artist, "Find matching artists", "<artist>" },
    { "title", 0, 0, G_OPTION_ARG_STRING, &audio_title, "Find matching titles", "<title>" },
    { "filter", 0, 0, G_OPTION_ARG_STRING, &audio_filter, "Find matching titles", "<title>" },
    { NULL },
};

int main (int argc, const char **argv)
{
    GError *error = NULL;
    TrackerSparqlConnection *connection;
    TrackerSparqlCursor *cursor;
    GOptionContext *context;
    const gchar *query;

    context = g_option_context_new ("- Search using multimedia metadata");
    g_option_context_add_main_entries (context, entries, NULL);
    if (!g_option_context_parse (context, &argc, (gchar***)&argv, &error)) {
        g_printf ("option parsing failed: %s\n", error->message);
        exit(1);
    }

    /* Build query manually */
    /* Don't care about memory leaks */
    query = "SELECT nie:url(?u) WHERE {\n";
    if (audio_album) {
        query = g_strdup_printf ("%s?u nmm:musicAlbum ?album . ?album nmm:albumTitle '%s'.\n", query, audio_album);
    } if (audio_artist) {
        query = g_strdup_printf ("%s?u nmm:performer ?performer . ?performer nmm:artistName '%s'.\n", query, audio_artist);
    } if (audio_title) {
        query = g_strdup_printf ("%s?u nie:title '%s' \n", query, audio_title);
    } if (audio_filter) {
        query = g_strdup_printf ("%s?u nie:url ?url FILTER regex(str(?url), '%s')\n", query, audio_filter);
    }
    query = g_strdup_printf("%s}", query);

    /* Everything after this is copied from the Tracker SPARQL Query example */

    /* Initialize GLib type system */
    g_type_init ();

    /* As we know only read-only queries will be done, it's enough
     * to use a connection with only direct-access setup. The NULL
     * represents a possible GCancellable.
     */
    connection = tracker_sparql_connection_get_direct (NULL, &error);
    if (!connection) {
        g_printerr ("Couldn't obtain a direct connection to the Tracker store: %s",
                    error ? error->message : "unknown error");
        g_clear_error (&error);

        return 1;
    }

    /* Make a synchronous query to the store */
    cursor = tracker_sparql_connection_query (connection, query, NULL, &error);

    if (error) {
        /* Some error happened performing the query, not good */
        g_printerr ("Couldn't query the Tracker Store: '%s'",
                    error ? error->message : "unknown error");
        g_clear_error (&error);

        return 1;
    }

    /* Check results... */
    if (!cursor) {
        g_print ("No results found :-/\n");
    } else {
        gint i = 0;

        /* Iterate, synchronously, the results... */
        while (tracker_sparql_cursor_next (cursor, NULL, &error)) {
            g_print ("Result [%d]: %s\n",
	             i++,
	             tracker_sparql_cursor_get_string (cursor, 0, NULL));
        }

        //g_print ("A total of '%d' results were found\n", i);

        g_object_unref (cursor);
    }

    g_object_unref (connection);

    return 0;
}
