#!/bin/bash
# vim: set sts=4 sw=4 et tw=0 :

set -e

TESTDIR=$(cd $(dirname $0); pwd; cd - &>/dev/null)
. "${TESTDIR}/config.sh"
. "${TESTDIR}/../../common/tracker-utils.sh"

#########
# Setup #
#########
_no_index_dirs() {
    local key
    key=$(get_gsettings_key "${TRACKER_MINER_SCHEMA}" index-single-directories)
    [[ $key != "@as []" ]] && return 1
    key=$(get_gsettings_key "${TRACKER_MINER_SCHEMA}" index-recursive-directories)
    [[ $key != "@as []" ]] && return 1
    return 0
}

trap "setup_failure" ERR

# Need a DBus session for this test
ensure_dbus_session

echo "Killing all tracker processes and wiping DB"
# Kill all tracker processes, wipe db
tracker-control -r

setup_success

###########
# Execute #
###########
TRACKER_MINER_LOG="${WORKDIR}/tracker-miner.log"

_run_automounter() {
    "${TESTLIBDIR}/automount-removable-device" &
    AUTOMOUNT_CMD_PID=$!
}

_kill_automounter() {
    kill -s TERM $AUTOMOUNT_CMD_PID
}

_unmount_drive() {
    umount "${MOUNT_PATH}"
}

check_index_mass_storage_results() {
    local ret=0

    say "Restarting Tracker miners ..."
    tracker-control -s
    _monitor_indexing_status

    say "Waiting for indexing to finish ..."
    _spin_on_indexing_finish

    say "Checking index ..."
    _check_args_indexed "${1}"/* || ret=1

    say "Done; killing monitor ..."
    _kill_monitor
    _unmount_drive
    return $ret
}

trap "_kill_automounter; test_failure" ERR
trap "_kill_automounter" EXIT

_run_automounter

whine "Please insert storage ..."
MOUNT_PATH=$("${TESTLIBDIR}/wait-for-new-removable-mount")
say "Copying test media files to storage ..."
src_copy_contents "${MEDIA_RESOURCE_DIR}" "${MOUNT_PATH}"

src_test_pass "$MOUNT_PATH" <<<check_index_mass_storage_results

test_success
