/* vim: set sts=4 sw=4 et :
 *
 * Waits for a removable drive to be mounted, and then returns the mount path
 *
 */

#include <gio/gio.h>
#include <glib.h>
#include <glib/gprintf.h>

static GMainLoop *loop;

void
mount_added_cb (GVolumeMonitor *volume_monitor,
                GMount         *mount,
                gpointer        user_data)
{
    GFile *file;
    gchar *location;

    /* We don't use g_drive_is_media_removable() because it doesn't work */
    if (!g_mount_can_eject (mount)) {
        g_debug ("The media inserted is not removable");
        goto out;
    }

    file = g_mount_get_default_location (mount);
    location = g_file_get_parse_name (file);

    g_debug ("Removable drive found at: %s", location);
    g_printf ("%s\n", location);

    g_object_unref (file);
    g_main_loop_quit (loop);
out:
    return;
}

int
main (int   argc,
      char *argv[])
{
    GVolumeMonitor *volume_monitor;

    volume_monitor = g_volume_monitor_get ();

    g_signal_connect (volume_monitor, "mount-added",
                      G_CALLBACK (mount_added_cb), NULL);
    loop = g_main_loop_new (NULL, FALSE);
    g_main_loop_run (loop);
    return 0;
}
